@@ -62,7 +62,7 @@ def retry(num_of_retries: int = 3, timeout: int = 30):
         timeout: The number of seconds to wait between each retry
     """
     num_of_retries = 3
-    timeout = 2
+    timeout = 30
 
     def _retry(func):
         @wraps(func)
@@ -73,10 +73,14 @@ def retry(num_of_retries: int = 3, timeout: int = 30):
                 # Using general error to avoid any possible error dependencies.
                 except (ConnectionError, JSONDecodeError) as error:
                     logger.exception(error)
+                    print(f"Sleeping in {timeout}")
                     time.sleep(timeout)
                     if i == num_of_retries - 1:
                         raise error
                     continue
+                except Exception as error:
+                    print(error)
+                    logger.exception(error)
 
         return function_wrapper
 
